@@ -96,7 +96,7 @@ $file_scontri = file("$percorso_cartella_scontri/squadre$num_giocatori");
 $num_linee_file_scontri = count($file_scontri);
 $finito_scontri = "NO";
 $conta_cicli_while = 0;
-$num_giornata_campionato = 0;
+$num_giornata_campionato = $g_inizio_camp - 1;
 $giornata_scritta = $g_inizio_camp - 1;
 echo "<table align=\"center\">";
 $num_cella = 1;
