@@ -35,7 +35,24 @@ $copiare = "NO";
 } # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
 $lock = fopen("$percorso_cartella_dati/admin.lock","w+");
 flock($lock,2);
-$voti = @file($posizione_file);
+if ($file_voti_zippato == "SI") {
+$copiare = "NO";
+if (@copy($posizione_file,"$percorso_cartella_voti/votitmp.zip")) {
+include('./include/pclzip/pclzip.lib.php');
+$contenuto_file_voti = new PclZip("$percorso_cartella_voti/votitmp.zip");
+$voti = $contenuto_file_voti->extract(PCLZIP_OPT_EXTRACT_AS_STRING);
+if ($voti == 0) echo "<b>Errore nella decompressione del file zip.</b>";
+echo nl2br($list[0]['content']);
+$filevoti = fopen("$percorso_cartella_voti/voti$num_giornata.txt","w+");
+flock($filevoti,2);
+rewind($filevoti);
+fwrite($filevoti,$voti[0]['content']);
+flock($filevoti,3);
+fclose($filevoti);
+unlink("$percorso_cartella_voti/votitmp.zip");
+} # fine if (@copy($posizione_file,"$percorso_cartella_voti/votitmp.zip"))
+} # fine if ($file_voti_zippato == "SI")
+else $voti = @file($posizione_file);
 if (!$voti) {
 echo "<b>file non trovato.</b>";
 $copiare = "NO";
