@@ -32,7 +32,8 @@ if (!@is_file("$percorso_cartella_dati/$giornata_controlla")) break;
 else $giornata_ultima = $num1;
 } # fine for $num1
 
-if (!$giornata) $giornata = "giornata$giornata_ultima";
+$num_giornata_richiesta = substr($giornata,-2);
+if (!$giornata or $num_giornata_richiesta > $giornata_ultima) $giornata = "giornata$giornata_ultima";
 
 echo "<table width=\"100%\" align=\"center\"><tr><td width=\"33%\" align=\"left\">
 <form method=\"post\" action=\"guarda_giornata.php\">
@@ -43,6 +44,7 @@ echo "<table width=\"100%\" align=\"center\"><tr><td width=\"33%\" align=\"left\
  n <select name=\"giornata\">
 <option value=\"\">--</option>";
 for ($num1 = "01" ; $num1 <= $giornata_ultima ; $num1++) {
+if (strlen($num1) == 1) $num1 = "0".$num1;
 echo "<option value=\"giornata$num1\">$num1</option>";
 } # fine for $num1
 echo "</select></form></td>";
@@ -277,8 +279,9 @@ echo "</tr></table>";
 echo "<br><center>Giornata chiusa.</center><br>";
 } # fine if ($voti_esistenti == "SI")
 
+if ($target) $target = " target=\"$target\"";
 if (!$origine) $origine = "mercato.php";
-echo "<center><form method=\"post\" action=\"$origine\">
+echo "<center><form method=\"post\" action=\"$origine\"$target>
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
