@@ -32,6 +32,7 @@ $soldi_spesi = 0;
 $vecchio_proprietario = "";
 $nuovo_costo = "";
 $num_calciatori_posseduti = 0;
+$nuova_offerta = "NO";
 $lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
 flock($lock,2);
 
@@ -53,11 +54,20 @@ $trovato = "SI";
 $posizione = $num1;
 $costo = $dati_calciatore[3];
 $proprietario_vero = $proprietario;
+if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###") {
 $vecchio_proprietario = $dati_calciatore[6];
 $vecchio_costo = $dati_calciatore[7];
 $vecchio_costo = togli_acapo($vecchio_costo);
 $nuovo_costo = $dati_calciatore[8];
 $nuovo_costo = togli_acapo($nuovo_costo);
+$prima_offerta = "NO";
+} # fine if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###")
+else {
+$vecchio_proprietario = "";
+$vecchio_costo = "";
+$nuovo_costo = "";
+$prima_offerta = "SI";
+} # fine else if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###")
 $tempo_off = $dati_calciatore[5];
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
@@ -76,6 +86,12 @@ if ($costo_mostra >= $valore_offerta) {
 $inserire = "NO";
 $frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
 } # fine if ($costo >= $valore_offerta)
+else {
+if ($prima_offerta == "SI" and ($costo_mostra + $min_rilancio_dopo_offerta_iniziale - 1) >= $valore_offerta) {
+$inserire = "NO";
+$frase .= "L'offerta non  abbastanza alta per comprare il calciatore (in quanto seconnda offerta si devono offrire almeno ".($costo_mostra + $min_rilancio_dopo_offerta_iniziale)." fanta-euro).<br>";
+} # fine if ($prima_offerta == "SI" and ($costo_mostra + $min_rilancio_dopo_offerta_iniziale - 1) >= $valore_offerta)
+} # fine else if ($costo >= $valore_offerta)
 } # fine if ($num_calciatore == $numero)
 } # fine for $num1
 
@@ -168,6 +184,8 @@ $minuto_attuale = date("i");
 $scadenza = date("YmdHi",mktime($ora_attuale+$aspetta_ore,$minuto_attuale+$aspetta_minuti,0,$mese_attuale,$giorno_attuale+$aspetta_giorni,$anno_attuale));
 $linea = "$num_calciatore,$nome,$ruolo,$valore_offerta,$nome_utente,$scadenza";
 
+if ($nuova_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $linea .= ",###PRIMA_OFFERTA###";
+
 if ($vecchio_proprietario) {
 $linea .= ",$vecchio_proprietario,$vecchio_costo";
 if ($vecchio_proprietario == $nome_utente) {
