@@ -76,14 +76,24 @@ $tempo_restante = "";
 if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
 if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
 $tempo_restante .= "$minuti_restanti m.";
+if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###") {
 $vecchio_proprietario = $dati_calciatore[6];
 $vecchio_costo = $dati_calciatore[7];
 $nuovo_costo = $dati_calciatore[8];
+$prima_offerta = "NO";
+} # fine if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###")
+else {
+$vecchio_proprietario = "";
+$vecchio_costo = "";
+$nuovo_costo = "";
+$prima_offerta = "SI";
+} # fine else if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###")
 } # fine else if ($sec_restanti < 0)
 if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2>(venduto da $vecchio_proprietario)</font>"; }
 else { $proprietario_mostra = $proprietario; }
 if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
 else { $costo_mostra = $costo; }
+if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= " (1)";
 echo"<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
