@@ -28,7 +28,7 @@ if ($pass_errata != "SI") {
 
 if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";
 
-$calciatori = file("$percorso_cartella_dati/calciatori.txt");
+$calciatori = file("$percorso_cartella_voti/calciatori.txt");
 $num_calciatori = count($calciatori);
 
 echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
@@ -45,15 +45,18 @@ $numero = togli_acapo($numero);
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
 $nome = togli_acapo($nome);
 $nome = ereg_replace("\"","",$nome);
-$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
-$ruolo = togli_acapo($ruolo);
-if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
-if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
-if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
-if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
+$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
+$s_ruolo = togli_acapo($s_ruolo);
+$ruolo = $s_ruolo;
+if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
+if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo = $considera_fantasisti_come;
+if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
+if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
+if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
+if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
 
 if ($ruolo == $ruolo_guarda or $ruolo_guarda == "tutti") {
-echo"<tr><td>$numero</td>
+echo"<tr><td align=\"center\"><a href=\"stat_calciatore.php?num_calciatore=$numero&ruolo_guarda=$ruolo_guarda&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">$numero</a></td>
 <td>$nome</td>
 <td>$ruolo</td>
 <td><a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a></td>
